#!/bin/bash

#################################################
# Define your variables
WKGDIR="/home/chuagh/1H28BE6"
AMBER_exe="/usr/local/amber/exe"
PBSA_DIR="/home/chuagh/bin/mm_pbsa"

PDB_FILE="1H28BE6"

PREFIX="1H28"
COMPT="1H28BE6_vac.top"	#example: complex_vac.top
RECPT="1H28B_vac.top"	#example: rec_vac.top
LIGPT="1H28E6_vac.top"	#example: lig_vac.top
TRAJ=(1H28BE6_md3.crd 1H28BE6_md4.crd 1H28BE6_md5.crd 1H28BE6_md6.crd 1H28BE6_md7.crd)

NSTART=1
NSTOP=5000
NFREQ=100
NUM_ENTROPY_FRAMES=10

CHARGE_FILE="/home/chuagh/bin/mm_pbsa/my_amber94_delphi.crg"
SIZE_FILE="/home/chuagh/bin/mm_pbsa/my_parse_delphi.siz"

################################################
TRAJ_NUM=${#TRAJ[*]}
NUM_ENTHALPY_FRAMES=`expr ${NSTOP}/${NFREQ}`

##################################################

#Generate directories
rm -r GF
rm -r ENTHALPY
rm -r ENTROPY
rm -r ENTROPY_GF
mkdir GF
mkdir ENTHALPY
mkdir ENTROPY
mkdir ENTROPY_GF

#######################################################
## Generate pdb file from .top and .crd files
/usr/local/amber/exe/ambpdb -p ${PDB_FILE}.top < ${PDB_FILE}.crd > ${PDB_FILE}_box.pdb

## Find the largest residue id of protein and largest residue id of water
cat ${PDB_FILE}_box.pdb | grep "OXT" | awk '{print $2}' > tmp
RSTART=1
RSTOP=`tail -2 tmp | head -1`
LSTART=`expr ${RSTOP} + 1`
LSTOP=`tail -1 tmp`
rm -f tmp
NTOTAL=`tail -3 ${PDB_FILE}_box.pdb | head -1 | awk '{print $2}'`

cat ${PDB_FILE}_box.pdb | grep "OXT" | awk '{print $5}' > tmp
COMREC_START=1
COMREC_END=`tail -2 tmp | head -1`
COMLIG_START=`expr ${COMREC_END} + 1`
COMLIG_END=`tail -1 tmp`
COMPRI_START=1
COMPRI_END=${COMLIG_END}
RECRES_START=1
RECRES_END=${COMREC_END}
RECPRI_START=1
RECPRI_END=${COMREC_END}
RECMAP_START=1
RECMAP_END=${COMREC_END}
LIGRES_START=1
LIGRES_END=`expr ${COMLIG_END} - ${COMLIG_START} + 1`
LIGPRI_START=${LIGRES_START}
LIGPRI_END=${LIGRES_END}
LIGMAP_START=${COMLIG_START}
LIGMAP_END=${COMLIG_END}



############################################################
# Prepare GF.in
###########################################################
cat ${PBSA_DIR}/GF_part1.txt > ${WKGDIR}/GF/GF.in
echo "PREFIX                ${PREFIX}" >> ${WKGDIR}/GF/GF.in
echo "PATH                  ${WKGDIR}/GF" >> ${WKGDIR}/GF/GF.in
echo "#" >> ${WKGDIR}/GF/GF.in
echo "COMPLEX               1" >> ${WKGDIR}/GF/GF.in
echo "RECEPTOR              1" >> ${WKGDIR}/GF/GF.in
echo "LIGAND                1" >> ${WKGDIR}/GF/GF.in
echo "#" >> ${WKGDIR}/GF/GF.in
echo "COMPT                 ${WKGDIR}/${COMPT}">> ${WKGDIR}/GF/GF.in
echo "RECPT                 ${WKGDIR}/${RECPT}">> ${WKGDIR}/GF/GF.in
echo "LIGPT                 ${WKGDIR}/${LIGPT}">> ${WKGDIR}/GF/GF.in
echo "#" >> ${WKGDIR}/GF/GF.in
cat ${PBSA_DIR}/GF_part2.txt >> ${WKGDIR}/GF/GF.in
echo "NTOTAL                ${NTOTAL}">>${WKGDIR}/GF/GF.in
echo "NSTART                ${NSTART}" >>${WKGDIR}/GF/GF.in
echo "NSTOP                 ${NSTOP}" >>${WKGDIR}/GF/GF.in
echo "NFREQ                 ${NFREQ}" >>${WKGDIR}/GF/GF.in
echo "#" >>${WKGDIR}/GF/GF.in
echo "NUMBER_LIG_GROUPS     1" >>${WKGDIR}/GF/GF.in
echo "LSTART                ${LSTART}" >>${WKGDIR}/GF/GF.in
echo "LSTOP                 ${LSTOP}" >>${WKGDIR}/GF/GF.in
echo "NUMBER_REC_GROUPS     1" >>${WKGDIR}/GF/GF.in
echo "RSTART                ${RSTART}" >>${WKGDIR}/GF/GF.in
echo "RSTOP                 ${RSTOP}" >>${WKGDIR}/GF/GF.in
echo "#" >> ${WKGDIR}/GF/GF.in
echo "#################################################################################" >>${WKGDIR}/GF/GF.in
echo "@TRAJECTORY" >>${WKGDIR}/GF/GF.in
echo "#" >> ${WKGDIR}/GF/GF.in
echo "# Trajectory names" >>${WKGDIR}/GF/GF.in
echo "#   The following trajectories are used to extract snapshots with "make_crd_hg":" >>${WKGDIR}/GF/GF.in
echo "#   Each trajectory name must be preceeded by the TRAJECTORY card." >>${WKGDIR}/GF/GF.in
echo "#   Subsequent trajectories are considered together; trajectories may be" >>${WKGDIR}/GF/GF.in
echo "#     in ascii as well as in .gz format." >>${WKGDIR}/GF/GF.in
echo "#   To be able to identify the title line, it must be identical in all files." >>${WKGDIR}/GF/GF.in

for ((i=0; i<${TRAJ_NUM}; i++))
do 
	echo "TRAJECTORY            ${TRAJ[$i]}" >>${WKGDIR}/GF/GF.in
done

echo "################################################################################" >>${WKGDIR}/GF/GF.in
echo "@PROGRAMS" >>${WKGDIR}/GF/GF.in
echo "#" >> ${WKGDIR}/GF/GF.in
echo "# Program executables" >>${WKGDIR}/GF/GF.in
echo "#" >> ${WKGDIR}/GF/GF.in
echo "DELPHI                /home/gohlke/src/delphi.98/exe.R10000/delphi">>${WKGDIR}/GF/GF.in
echo "#" >> ${WKGDIR}/GF/GF.in
echo "################################################################################" >>${WKGDIR}/GF/GF.in


#################################################################
# Prepare enthalpy.in
#################################################################
cat ${PBSA_DIR}/enthalpy_part1.txt > ${WKGDIR}/ENTHALPY/enthalpy.in
echo "PREFIX                ${PREFIX}" >> ${WKGDIR}/ENTHALPY/enthalpy.in
echo "PATH                  ${WKGDIR}/GF/">>${WKGDIR}/ENTHALPY/enthalpy.in
echo "#" >>${WKGDIR}/ENTHALPY/enthalpy.in
echo "COMPLEX               1">>${WKGDIR}/ENTHALPY/enthalpy.in
echo "RECEPTOR              1">>${WKGDIR}/ENTHALPY/enthalpy.in
echo "LIGAND                1">>${WKGDIR}/ENTHALPY/enthalpy.in
echo "#" >>${WKGDIR}/ENTHALPY/enthalpy.in
echo "COMPT                 ${WKGDIR}/${COMPT}">>${WKGDIR}/ENTHALPY/enthalpy.in
echo "RECPT                 ${WKGDIR}/${RECPT}">>${WKGDIR}/ENTHALPY/enthalpy.in
echo "LIGPT                 ${WKGDIR}/${LIGPT}">>${WKGDIR}/ENTHALPY/enthalpy.in
cat ${PBSA_DIR}/enthalpy_part2.txt >> ${WKGDIR}/ENTHALPY/enthalpy.in
echo "CHARGE                ${CHARGE_FILE}">>${WKGDIR}/ENTHALPY/enthalpy.in
echo "SIZE                ${SIZE_FILE}">>${WKGDIR}/ENTHALPY/enthalpy.in
cat ${PBSA_DIR}/enthalpy_part3.txt >> ${WKGDIR}/ENTHALPY/enthalpy.in
 
##########################################################################
# Prepare entropy.in
##########################################################################
cat ${PBSA_DIR}/entropy_part1.txt > ${WKGDIR}/ENTROPY/entropy.in
echo "PREFIX                ${PREFIX}">>${WKGDIR}/ENTROPY/entropy.in
echo "PATH		    ${WKGDIR}/ENTROPY_GF/">>${WKGDIR}/ENTROPY/entropy.in
echo "#">>${WKGDIR}/ENTROPY/entropy.in
echo "COMPLEX               1">>${WKGDIR}/ENTROPY/entropy.in
echo "RECEPTOR              1">>${WKGDIR}/ENTROPY/entropy.in
echo "LIGAND                1">>${WKGDIR}/ENTROPY/entropy.in
echo "#">>${WKGDIR}/ENTROPY/entropy.in
echo "COMPT                 ${WKGDIR}/${COMPT}">>${WKGDIR}/ENTROPY/entropy.in
echo "RECPT                 ${WKGDIR}/${RECPT}">>${WKGDIR}/ENTROPY/entropy.in
echo "LIGPT                 ${WKGDIR}/${LIGPT}">>${WKGDIR}/ENTROPY/entropy.in
echo "">>${WKGDIR}/ENTROPY/entropy.in
cat ${PBSA_DIR}/entropy_part2.txt >> ${WKGDIR}/ENTROPY/entropy.in


#########################################################
# Prepare file for copying files to ENTROPY_GF
# Filename: get_entropy_gf.sh
#########################################################
echo "#!/bin/bash" > ${WKGDIR}/get_entropy_gf.sh
echo " "  >>  ${WKGDIR}/get_entropy_gf.sh
echo "MAX_FILE=\`ls ${WKGDIR}/GF/${PREFIX}_com.crd.* -1 | cut -d \. -f3 | sort -n | tail -1\`" >>  ${WKGDIR}/get_entropy_gf.sh
echo "OFFSET=\`expr \${MAX_FILE} / ${NUM_ENTROPY_FRAMES}\`" >>  ${WKGDIR}/get_entropy_gf.sh
echo " " >>  ${WKGDIR}/get_entropy_gf.sh
echo "for i in \`seq 1 ${NUM_ENTROPY_FRAMES}\`">>${WKGDIR}/get_entropy_gf.sh
echo "do">>${WKGDIR}/get_entropy_gf.sh
echo "j=\`expr \${i} - 1\`">>${WKGDIR}/get_entropy_gf.sh
echo "j=\`expr \${j} \\* \${OFFSET} + 1\`">>${WKGDIR}/get_entropy_gf.sh
echo "cp ${WKGDIR}/GF/${PREFIX}_com.crd.\${j} ${WKGDIR}/ENTROPY_GF/${PREFIX}_com.crd.\${i}" >>${WKGDIR}/get_entropy_gf.sh
echo "cp ${WKGDIR}/GF/${PREFIX}_rec.crd.\${j} ${WKGDIR}/ENTROPY_GF/${PREFIX}_rec.crd.\${i}" >>${WKGDIR}/get_entropy_gf.sh
echo "cp ${WKGDIR}/GF/${PREFIX}_lig.crd.\${j} ${WKGDIR}/ENTROPY_GF/${PREFIX}_lig.crd.\${i}" >>${WKGDIR}/get_entropy_gf.sh
echo "done">>${WKGDIR}/get_entropy_gf.sh


#########################################################
# Prepare decomp.in
#########################################################
rm -rf decomp
mkdir decomp
cat ${PBSA_DIR}/decomp_part1.txt > ${WKGDIR}/decomp/decomp.in
echo "PREFIX                ${PREFIX}">> ${WKGDIR}/decomp/decomp.in
echo "PATH                  ${WKGDIR}/GF/">> ${WKGDIR}/decomp/decomp.in
echo "#">> ${WKGDIR}/decomp/decomp.in
echo "COMPLEX               1">> ${WKGDIR}/decomp/decomp.in
echo "RECEPTOR              1">> ${WKGDIR}/decomp/decomp.in
echo "LIGAND                1">> ${WKGDIR}/decomp/decomp.in
echo "#">> ${WKGDIR}/decomp/decomp.in
echo "COMPT                 ${WKGDIR}/${COMPT}">> ${WKGDIR}/decomp/decomp.in
echo "RECPT                 ${WKGDIR}/${RECPT}">> ${WKGDIR}/decomp/decomp.in
echo "LIGPT                 ${WKGDIR}/${LIGPT}">> ${WKGDIR}/decomp/decomp.in
echo "#">> ${WKGDIR}/decomp/decomp.in
cat ${PBSA_DIR}/decomp_part2.txt >> ${WKGDIR}/decomp/decomp.in
echo "DCTYPE                2">> ${WKGDIR}/decomp/decomp.in
echo "#">> ${WKGDIR}/decomp/decomp.in
echo "COMREC                ${COMREC_START}-${COMREC_END}">> ${WKGDIR}/decomp/decomp.in
echo "COMLIG                ${COMLIG_START}-${COMLIG_END}">> ${WKGDIR}/decomp/decomp.in
echo "COMPRI                ${COMPRI_START}-${COMPRI_END}">> ${WKGDIR}/decomp/decomp.in
echo "RECRES                ${RECRES_START}-${RECRES_END}">> ${WKGDIR}/decomp/decomp.in
echo "RECPRI                ${RECPRI_START}-${RECPRI_END}">> ${WKGDIR}/decomp/decomp.in
echo "RECMAP                ${RECMAP_START}-${RECMAP_END}">> ${WKGDIR}/decomp/decomp.in
echo "LIGRES                ${LIGRES_START}-${LIGRES_END}">> ${WKGDIR}/decomp/decomp.in
echo "LIGPRI                ${LIGPRI_START}-${LIGPRI_END}">> ${WKGDIR}/decomp/decomp.in
echo "LIGMAP                ${LIGMAP_START}-${LIGMAP_END}">> ${WKGDIR}/decomp/decomp.in
cat ${PBSA_DIR}/decomp_part3.txt >> ${WKGDIR}/decomp/decomp.in
echo "CHARGE                ${PBSA_DIR}/my_amber94_delphi.crg">> ${WKGDIR}/decomp/decomp.in
echo "SIZE                  ${PBSA_DIR}/my_parse_delphi.siz">> ${WKGDIR}/decomp/decomp.in
cat ${PBSA_DIR}/decomp_part4.txt >> ${WKGDIR}/decomp/decomp.in


##########################################################
# prepare run_pbsa file
##########################################################
echo "#!/bin/bash" > ${WKGDIR}/run_pbsa.sh
echo " " >>  ${WKGDIR}/run_pbsa.sh
echo "bsub -J ${PREFIX}_GF -n 4 -q long ${AMBER_exe}/mm_pbsa.pl ${WKGDIR}/GF/GF.in" >> ${WKGDIR}/run_pbsa.sh
echo "bjobs -J ${PREFIX}_GF > tmp" >> ${WKGDIR}/run_pbsa.sh
echo "jobID=\`tail -1 tmp | awk '{print \$1}'\`" >> ${WKGDIR}/run_pbsa.sh
echo "echo \"cd ${WKGDIR}/ENTHALPY\" > tmp" >> ${WKGDIR}/run_pbsa.sh
echo "echo \"bsub -w 'done(\${jobID})' -J ${PREFIX}_EGF -n 1 ${WKGDIR}/get_entropy_gf.sh\" >> tmp" >>${WKGDIR}/run_pbsa.sh
echo "echo \"bsub -w 'done(\${jobID})' -J ${PREFIX}_ENTHALPY -q long -n 4 ${AMBER_exe}/mm_pbsa.pl ${WKGDIR}/ENTHALPY/enthalpy.in\">>tmp" >>${WKGDIR}/run_pbsa.sh
echo "chmod +x tmp" >> ${WKGDIR}/run_pbsa.sh
echo "tmp" >> ${WKGDIR}/run_pbsa.sh
echo "bjobs -J ${PREFIX}_EGF >tmp">> ${WKGDIR}/run_pbsa.sh
echo "jobID=\`tail -1 tmp | awk '{print \$1}'\`" >> ${WKGDIR}/run_pbsa.sh
echo "echo \"cd ${WKGDIR}/ENTROPY\" > tmp"  >> ${WKGDIR}/run_pbsa.sh
echo "echo \"bsub -w 'done(\${jobID})' -q long -n 4 ${AMBER_exe}/mm_pbsa.pl ${WKGDIR}/ENTROPY/entropy.in\" >> tmp" >>${WKGDIR}/run_pbsa.sh
echo "echo \"bsub -w 'done(\${jobID})' -q long -n 1 ${AMBER_exe}/mm_pbsa.pl ${WKGDIR}/decomp/decomp.in\" >> tmp" >>${WKGDIR}/run_pbsa.sh
echo "tmp"  >>${WKGDIR}/run_pbsa.sh

chmod +x ${WKGDIR}/run_pbsa.sh
chmod +x ${WKGDIR}/get_entropy_gf.sh






